# IntegralElimination

This package implements the integral elimination algortihm described in :  
 
* François Lemaire and Louis Roussel. 
*Contribution to Integral Elimination*. 
Computer Algebra in Scientific Computing (CASC) 26th International 
Workshop, Sep 2024, Rennes, France. pp.215--235. 
URL: https://hal.science/hal-04570612. DOI: 10.1007/978-3-031-69070-9_13.

* François Lemaire and Louis Roussel. 
*Recent Advances on Integral Elimination*.
Proceedings of the 2025 International Symposium on Symbolic and Algebraic
Computation. ISSAC ’25. Association for Computing Machinery, 2025, pp. 249–257. 
URL: https://hal.science/hal-04965642. isbn: 9798400720758. DOI: 10.1145/3747199.3747568.

The source code is availaible at :
```
https://codeberg.org/louis-roussel/IntegralElimination
```
 
# Installation

* **Using pip**
```
python -m pip install IntegralElimination
```
* **Or by building and installing the package**
```
python -m pip install .
```

# How to use ?
Examples are available in the *examples* folder. 
<!-- 
# Details on the implentation
* This implementation in Python uses the SymPy package.
* The functions implemented are as close as possible to those in the articles above.
    * A slight modification as been made to the *update_exp* function to correctly handle exponentials that have already been defined. -->

# Contact


* [Louis Roussel](https://louis-roussel.github.io/) (louis.roussel@univ-lille.fr), Université de Lille, CNRS, Centrale Lille, UMR 9189 CRIStAL, F-59000 Lille, France

 